pub struct SerializableOutputAccount {
pub address: Bytes,
pub nonce: u64,
pub balance: Bytes,
pub storage_updates: HashMap<String, SerializableStorageUpdate>,
pub code: Bytes,
pub code_metadata: Bytes,
pub code_deployer_address: Bytes,
pub balance_delta: Bytes,
pub output_transfers: Vec<SerializableOutputTransfer>,
pub gas_used: u64,
}Fields
address: Bytesnonce: u64balance: Bytesstorage_updates: HashMap<String, SerializableStorageUpdate>code: Bytescode_metadata: Bytescode_deployer_address: Bytesbalance_delta: Bytesoutput_transfers: Vec<SerializableOutputTransfer>gas_used: u64Trait Implementations
Sourceimpl Clone for SerializableOutputAccount
impl Clone for SerializableOutputAccount
Sourcefn clone(&self) -> SerializableOutputAccount
fn clone(&self) -> SerializableOutputAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializableOutputAccount
impl Debug for SerializableOutputAccount
Sourceimpl Default for SerializableOutputAccount
impl Default for SerializableOutputAccount
Sourceimpl Message for SerializableOutputAccount
impl Message for SerializableOutputAccount
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for SerializableOutputAccount