pub struct SerializableVmOutput {
pub return_data: Vec<Bytes>,
pub return_code: u64,
pub return_message: String,
pub gas_remaining: u64,
pub gas_refund: Bytes,
pub output_accounts: HashMap<String, SerializableOutputAccount>,
pub deleted_accounts: Vec<Bytes>,
pub touched_accounts: Vec<Bytes>,
pub logs: Option<SerializableLogEntry>,
}Fields
return_data: Vec<Bytes>return_code: u64return_message: Stringgas_remaining: u64gas_refund: Bytesoutput_accounts: HashMap<String, SerializableOutputAccount>deleted_accounts: Vec<Bytes>touched_accounts: Vec<Bytes>logs: Option<SerializableLogEntry>Trait Implementations
Sourceimpl Clone for SerializableVmOutput
impl Clone for SerializableVmOutput
Sourcefn clone(&self) -> SerializableVmOutput
fn clone(&self) -> SerializableVmOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializableVmOutput
impl Debug for SerializableVmOutput
Sourceimpl Default for SerializableVmOutput
impl Default for SerializableVmOutput
Sourceimpl Message for SerializableVmOutput
impl Message for SerializableVmOutput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SerializableVmOutput
impl PartialEq for SerializableVmOutput
impl StructuralPartialEq for SerializableVmOutput