Module proto

Module proto 

Structs

AccountTokenData
AccountWrapMockData
Accounts
AdditionalAccountData
AdditionalAccountTokenData
AlteredAccount
BaseExecutionResult
BaseExecutionResult defines the dto that will hold base information about execution result
BaseMetaExecutionResult
BaseMetaExecutionResult contains a base execution result and additional validator and fee-related fields
Batch
Transaction holds all the data needed for a value transfer or SC call
BlockData
Body
BodyHeaderPair
BodyHeaderPair holds a body and header hash pair
BootstrapData
BootstrapData is used to store information that are needed for bootstrap
BootstrapHeaderInfo
BootstrapHeaderInfo is used to store information about a header
CodeEntry
CollapsedBn
CollapsedEn
CollapsedLn
DataTrieChange
DelegatedScVoteInfo
DelegatedWithAddress
DelegationConfig
DelegationContractList
DelegationContractStatus
DelegationManagement
DelegationMetaData
DelegatorData
Economics
Economics holds the block information for total supply and rewards
ElementInList
EpochByHash
EpochByHash is used to store information about a hash to know which epoch it belongs to
EpochStart
EpochStart holds the block information for end-of-epoch
EpochStartShardData
EpochStartShardData hold the last finalized headers hash and state root hash
EpochValidatorsWithAuction
EsdtConfig
EsdtDataV1
EsdtDataV2
EsdtRoles
Event
Event holds all the data needed for an event structure
ExecutionResult
ExecutionResult defines the dto that will hold information about execution result
ExecutionResultData
ExecutionResultInfo
ExecutionResultInfo contains a base execution result and the header round when the results was notarized
FeeInfo
FinalizedBlock
Fund
GasAndFees
GeneralProposal
GlobalFundData
GovernanceConfig
GovernanceConfigV2
Header
Header holds the metadata of a block. This is the part that is being hashed and run through consensus. The header holds the hash of the body and also the link to the previous block header hash
HeaderGasConsumption
HeaderProof
HeaderProof defines a proof for a specific header
HeaderV2
HeaderV2 extends the Header structure with extra fields for version 2
HeaderV3
HeaderV3 defines the structure of the header V3
HeartbeatV2
HeartbeatV2 represents the heartbeat message that is sent between peers from the same shard containing current node status
Log
Log holds all the data needed for a log structure
LogData
Message
Message defines the data needed by spos to communicate between nodes over network in all subrounds
MetaBlock
MetaBlock holds the data that will be saved to the metachain each round
MetaBlockV3
MetaBlockV3 holds all the fields needed for a meta block v3. This is the part that is being hashed and run through consensus.
MetaExecutionResult
MetaExecutionResult contains a base meta execution result and extra fields for meta block results
MetaExecutionResultInfo
MetaExecutionResultInfo contains a base meta execution result and the header round when the results was notarized
MetaTriggerRegistry
MetaTriggerRegistryV3
MiniBlock
MiniBlockHeader
MiniBlockHeaderReserved
MiniBlockReserved
MiniBlocksInMeta
MiniBlocksInMeta is used to store all mini blocks hashes for a metablock hash
MiniblockMetadata
MiniblockMetadata is used to store information about a history transaction
NodesCoordinatorRegistryWithAuction
NodesData
OngoingVotedList
OngoingVotedListV2
OutportBlock
OutportConfig
Payload
Payload represents the DTO used as payload for both HeartbeatV2 and PeerAuthentication messages
PeerAccountData
PeerAccountData represents the data that defines the PeerAccount
PeerAuthentication
PeerAuthentication represents the DTO used to pass peer authentication information such as public key, peer id, signature, payload and the signature. This message is used to link the peerID with the associated public key
PeerChange
PeerChange holds a change in one peer to shard assignation
PeerData
PeerData holds information about actions taken by a peer:
PeerShard
PeerShard represents the data regarding a peer’s shard
PendingMiniBlocksInfo
PendingMiniBlocksInfo is used to store information about the number of pending miniblocks
ProcessedBlockNonce
ProcessedBlock is used to store nonce of the latest processed block
PubKeys
Receipt
Receipt holds all the data needed for a transaction receipt
RequestData
RequestData holds the requested data This struct will be serialized and sent to the other peers
ResultsHashesByTxHash
ResultsHashesByTxHash is used to store smart contract results hashes and receipt hash for a transaction hash
RewardComputationData
RewardInfo
RewardTx
RewardTx holds the data for a reward transaction
RoundInfo
RoundNum
RoundsInfo
ScResultsHashesAndEpoch
ScrHashesAndEpoch is used to store smart contract results and epoch
ScheduledScRs
ScrInfo
SerializableValidator
Shard
ShardData
ShardData holds the block information sent by the shards to the metachain
ShardDataProposal
ShardDataProposal holds the block information proposed by the shards
ShardTriggerRegistry
ShardTriggerRegistryV2
ShardTriggerRegistryV3
ShardValidatorInfo
ShardValidatorInfo represents the data regarding a validator that is stored in the PeerMiniblocks
SignRate
SignRate is used to keep the number of success and failed signings
SmartContractResult
StakedDataV10
StakedDataV11
StakedDataV20
StakingNodesConfig
StateAccess
StateAccesses
StateAccessesForBlock
SupplyEsdt
SupplyESDT is used to store information a shard esdt token supply
TokenMetaData
TopicMessage
Transaction
Transaction holds all the data needed for a value transfer or SC call
TransactionPool
TrieLeafData
TxInfo
UnstakedValue
UserAccountData
ValidatorConfig
ValidatorDataV1
ValidatorDataV2
ValidatorInfo
ValidatorInfo represents the data regarding a validator that is verified by the metaNodes
ValidatorRatingInfo
ValidatorStatistics
ValidatorStatistics holds information about a validator
Validators
ValidatorsPubKeys
ValidatorsRating
WaitingList
WsMessage
WsMessage contains all the information needed for a WebSocket message

Enums

ActionType
MiniBlockState
PeerAction
PeerAction type represents the possible events that a node can trigger for the metachain to notarize
ProcessingType
RequestDataType
RequestDataType represents the data type for the requested data
Type
Type identifies the type of the block
VoteValueType