#[repr(i32)]pub enum PeerAction {
InvalidAction = 0,
PeerRegistration = 1,
PeerUnstaking = 2,
PeerDeregistration = 3,
PeerJailed = 4,
PeerUnJailed = 5,
PeerSlashed = 6,
PeerReStake = 7,
}Expand description
PeerAction type represents the possible events that a node can trigger for the metachain to notarize
Variants
InvalidAction = 0
PeerRegistration = 1
PeerUnstaking = 2
PeerDeregistration = 3
PeerJailed = 4
PeerUnJailed = 5
PeerSlashed = 6
PeerReStake = 7
Implementations
Sourceimpl PeerAction
impl PeerAction
Sourceimpl PeerAction
impl PeerAction
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.