#[repr(i32)]pub enum RequestDataType {
InvalidType = 0,
HashType = 1,
HashArrayType = 2,
NonceType = 3,
EpochType = 4,
ChunkType = 5,
}Expand description
RequestDataType represents the data type for the requested data
Variants
InvalidType = 0
Invalid
HashType = 1
HashType indicates that the request data object is of type hash
HashArrayType = 2
HashArrayType that the request data object contains a serialised array of hashes
NonceType = 3
NonceType indicates that the request data object is of type nonce (uint64)
EpochType = 4
EpochType indicates that the request data object is of type epoch
ChunkType = 5
ChunkType indicates that the request data object is of type chunk
Implementations
Sourceimpl RequestDataType
impl RequestDataType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.