pub struct AdditionalAccountData {
pub is_sender: bool,
pub balance_changed: bool,
pub current_owner: String,
pub user_name: String,
pub developer_rewards: String,
pub code_hash: Bytes,
pub root_hash: Bytes,
pub code_metadata: Bytes,
}Fields
is_sender: boolbalance_changed: boolcurrent_owner: Stringuser_name: Stringdeveloper_rewards: Stringcode_hash: Bytesroot_hash: Bytescode_metadata: BytesTrait Implementations
Sourceimpl Clone for AdditionalAccountData
impl Clone for AdditionalAccountData
Sourcefn clone(&self) -> AdditionalAccountData
fn clone(&self) -> AdditionalAccountData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdditionalAccountData
impl Debug for AdditionalAccountData
Sourceimpl Default for AdditionalAccountData
impl Default for AdditionalAccountData
Sourceimpl Hash for AdditionalAccountData
impl Hash for AdditionalAccountData
Sourceimpl Message for AdditionalAccountData
impl Message for AdditionalAccountData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AdditionalAccountData
impl PartialEq for AdditionalAccountData
impl Eq for AdditionalAccountData
impl StructuralPartialEq for AdditionalAccountData