pub struct BaseMetaExecutionResult {
pub base_execution_result: Option<BaseExecutionResult>,
pub validator_stats_root_hash: Bytes,
pub accumulated_fees_in_epoch: Bytes,
pub dev_fees_in_epoch: Bytes,
}Expand description
BaseMetaExecutionResult contains a base execution result and additional validator and fee-related fields
Fields
base_execution_result: Option<BaseExecutionResult>validator_stats_root_hash: Bytesaccumulated_fees_in_epoch: Bytesdev_fees_in_epoch: BytesTrait Implementations
Sourceimpl Clone for BaseMetaExecutionResult
impl Clone for BaseMetaExecutionResult
Sourcefn clone(&self) -> BaseMetaExecutionResult
fn clone(&self) -> BaseMetaExecutionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaseMetaExecutionResult
impl Debug for BaseMetaExecutionResult
Sourceimpl Default for BaseMetaExecutionResult
impl Default for BaseMetaExecutionResult
Sourceimpl Hash for BaseMetaExecutionResult
impl Hash for BaseMetaExecutionResult
Sourceimpl Message for BaseMetaExecutionResult
impl Message for BaseMetaExecutionResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BaseMetaExecutionResult
impl PartialEq for BaseMetaExecutionResult
impl Eq for BaseMetaExecutionResult
impl StructuralPartialEq for BaseMetaExecutionResult