pub struct BootstrapData {
pub last_header: Option<BootstrapHeaderInfo>,
pub last_cross_notarized_headers: Vec<BootstrapHeaderInfo>,
pub last_self_notarized_headers: Vec<BootstrapHeaderInfo>,
pub processed_mini_blocks: Vec<MiniBlocksInMeta>,
pub pending_mini_blocks: Vec<PendingMiniBlocksInfo>,
pub nodes_coordinator_config_key: Bytes,
pub epoch_start_trigger_config_key: Bytes,
pub highest_final_block_nonce: u64,
pub last_round: i64,
}Expand description
BootstrapData is used to store information that are needed for bootstrap
Fields
last_header: Option<BootstrapHeaderInfo>last_cross_notarized_headers: Vec<BootstrapHeaderInfo>last_self_notarized_headers: Vec<BootstrapHeaderInfo>processed_mini_blocks: Vec<MiniBlocksInMeta>pending_mini_blocks: Vec<PendingMiniBlocksInfo>nodes_coordinator_config_key: Bytesepoch_start_trigger_config_key: Byteshighest_final_block_nonce: u64last_round: i64Trait Implementations
Sourceimpl Clone for BootstrapData
impl Clone for BootstrapData
Sourcefn clone(&self) -> BootstrapData
fn clone(&self) -> BootstrapData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapData
impl Debug for BootstrapData
Sourceimpl Default for BootstrapData
impl Default for BootstrapData
Sourceimpl Message for BootstrapData
impl Message for BootstrapData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BootstrapData
impl PartialEq for BootstrapData
impl StructuralPartialEq for BootstrapData