pub struct DataTrieChange {
pub type: i32,
pub key: Bytes,
pub val: Bytes,
pub version: u32,
pub operation: u32,
}Fields
type: i32key: Bytesval: Bytesversion: u32operation: u32Implementations
Sourceimpl DataTrieChange
impl DataTrieChange
Sourcepub fn type(&self) -> ActionType
pub fn type(&self) -> ActionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ActionType)
pub fn set_type(&mut self, value: ActionType)
Sets type to the provided enum value.