pub struct DelegationConfig {
pub max_delegation_cap: Bytes,
pub initial_owner_funds: Bytes,
pub automatic_activation: bool,
pub changeable_service_fee: bool,
pub created_nonce: u64,
pub un_bond_period_in_epochs: u32,
pub check_cap_on_re_delegate_rewards: bool,
}Fields
max_delegation_cap: Bytesinitial_owner_funds: Bytesautomatic_activation: boolchangeable_service_fee: boolcreated_nonce: u64un_bond_period_in_epochs: u32check_cap_on_re_delegate_rewards: boolTrait Implementations
Sourceimpl Clone for DelegationConfig
impl Clone for DelegationConfig
Sourcefn clone(&self) -> DelegationConfig
fn clone(&self) -> DelegationConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DelegationConfig
impl Debug for DelegationConfig
Sourceimpl Default for DelegationConfig
impl Default for DelegationConfig
Sourceimpl Hash for DelegationConfig
impl Hash for DelegationConfig
Sourceimpl Message for DelegationConfig
impl Message for DelegationConfig
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DelegationConfig
impl PartialEq for DelegationConfig
impl Eq for DelegationConfig
impl StructuralPartialEq for DelegationConfig