pub struct EpochStartShardData {
pub shard_id: u32,
pub epoch: u32,
pub round: u64,
pub nonce: u64,
pub header_hash: Bytes,
pub root_hash: Bytes,
pub scheduled_root_hash: Bytes,
pub first_pending_meta_block: Bytes,
pub last_finished_meta_block: Bytes,
pub pending_mini_block_headers: Vec<MiniBlockHeader>,
}Expand description
EpochStartShardData hold the last finalized headers hash and state root hash
Fields
shard_id: u32epoch: u32round: u64nonce: u64header_hash: Bytesroot_hash: Bytesscheduled_root_hash: Bytesfirst_pending_meta_block: Byteslast_finished_meta_block: Bytespending_mini_block_headers: Vec<MiniBlockHeader>Trait Implementations
Sourceimpl Clone for EpochStartShardData
impl Clone for EpochStartShardData
Sourcefn clone(&self) -> EpochStartShardData
fn clone(&self) -> EpochStartShardData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EpochStartShardData
impl Debug for EpochStartShardData
Sourceimpl Default for EpochStartShardData
impl Default for EpochStartShardData
Sourceimpl Message for EpochStartShardData
impl Message for EpochStartShardData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EpochStartShardData
impl PartialEq for EpochStartShardData
impl StructuralPartialEq for EpochStartShardData