pub struct EsdtDataV2 {Show 21 fields
pub owner_address: Bytes,
pub token_name: Bytes,
pub ticker_name: Bytes,
pub token_type: Bytes,
pub mintable: bool,
pub burnable: bool,
pub can_pause: bool,
pub can_freeze: bool,
pub can_wipe: bool,
pub upgradable: bool,
pub can_change_owner: bool,
pub is_paused: bool,
pub minted_value: Bytes,
pub burnt_value: Bytes,
pub num_decimals: u32,
pub can_add_special_roles: bool,
pub nft_create_stopped: bool,
pub can_transfer_nft_create_role: bool,
pub special_roles: Vec<EsdtRoles>,
pub num_wiped: u32,
pub can_create_multi_shard: bool,
}Fields
owner_address: Bytestoken_name: Bytesticker_name: Bytestoken_type: Bytesmintable: boolburnable: boolcan_pause: boolcan_freeze: boolcan_wipe: boolupgradable: boolcan_change_owner: boolis_paused: boolminted_value: Bytesburnt_value: Bytesnum_decimals: u32can_add_special_roles: boolnft_create_stopped: boolcan_transfer_nft_create_role: boolspecial_roles: Vec<EsdtRoles>num_wiped: u32can_create_multi_shard: boolTrait Implementations
Sourceimpl Clone for EsdtDataV2
impl Clone for EsdtDataV2
Sourcefn clone(&self) -> EsdtDataV2
fn clone(&self) -> EsdtDataV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EsdtDataV2
impl Debug for EsdtDataV2
Sourceimpl Default for EsdtDataV2
impl Default for EsdtDataV2
Sourceimpl Message for EsdtDataV2
impl Message for EsdtDataV2
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EsdtDataV2
impl PartialEq for EsdtDataV2
impl StructuralPartialEq for EsdtDataV2