pub struct ExecutionResultData {
pub header_nonce: u64,
pub timestamp_ms: u64,
pub body: Option<Body>,
pub intra_shard_mini_blocks: Vec<MiniBlock>,
pub transaction_pool: Option<TransactionPool>,
pub altered_accounts: HashMap<String, AlteredAccount>,
pub header_gas_consumption: Option<HeaderGasConsumption>,
}Fields
header_nonce: u64timestamp_ms: u64body: Option<Body>intra_shard_mini_blocks: Vec<MiniBlock>transaction_pool: Option<TransactionPool>altered_accounts: HashMap<String, AlteredAccount>header_gas_consumption: Option<HeaderGasConsumption>Trait Implementations
Sourceimpl Clone for ExecutionResultData
impl Clone for ExecutionResultData
Sourcefn clone(&self) -> ExecutionResultData
fn clone(&self) -> ExecutionResultData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionResultData
impl Debug for ExecutionResultData
Sourceimpl Default for ExecutionResultData
impl Default for ExecutionResultData
Sourceimpl Message for ExecutionResultData
impl Message for ExecutionResultData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ExecutionResultData
impl PartialEq for ExecutionResultData
impl StructuralPartialEq for ExecutionResultData