pub struct Header {Show 24 fields
pub nonce: u64,
pub prev_hash: Bytes,
pub prev_rand_seed: Bytes,
pub rand_seed: Bytes,
pub pub_keys_bitmap: Bytes,
pub shard_id: u32,
pub time_stamp: u64,
pub round: u64,
pub epoch: u32,
pub block_body_type: i32,
pub signature: Bytes,
pub leader_signature: Bytes,
pub mini_block_headers: Vec<MiniBlockHeader>,
pub peer_changes: Vec<PeerChange>,
pub root_hash: Bytes,
pub meta_block_hashes: Vec<Bytes>,
pub tx_count: u32,
pub epoch_start_meta_hash: Bytes,
pub receipts_hash: Bytes,
pub chain_id: Bytes,
pub software_version: Bytes,
pub accumulated_fees: Bytes,
pub developer_fees: Bytes,
pub reserved: Bytes,
}Expand description
Header holds the metadata of a block. This is the part that is being hashed and run through consensus. The header holds the hash of the body and also the link to the previous block header hash
Fields
nonce: u64prev_hash: Bytesprev_rand_seed: Bytesrand_seed: Bytespub_keys_bitmap: Bytesshard_id: u32time_stamp: u64round: u64epoch: u32block_body_type: i32signature: Bytesleader_signature: Bytesmini_block_headers: Vec<MiniBlockHeader>peer_changes: Vec<PeerChange>root_hash: Bytesmeta_block_hashes: Vec<Bytes>tx_count: u32epoch_start_meta_hash: Bytesreceipts_hash: Byteschain_id: Bytessoftware_version: Bytesaccumulated_fees: Bytesdeveloper_fees: Bytesreserved: BytesImplementations
Sourceimpl Header
impl Header
Sourcepub fn block_body_type(&self) -> Type
pub fn block_body_type(&self) -> Type
Returns the enum value of block_body_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_block_body_type(&mut self, value: Type)
pub fn set_block_body_type(&mut self, value: Type)
Sets block_body_type to the provided enum value.