pub struct HeaderProof {
pub pub_keys_bitmap: Bytes,
pub aggregated_signature: Bytes,
pub header_hash: Bytes,
pub header_epoch: u32,
pub header_nonce: u64,
pub header_shard_id: u32,
pub header_round: u64,
pub is_start_of_epoch: bool,
}Expand description
HeaderProof defines a proof for a specific header
Fields
pub_keys_bitmap: Bytesaggregated_signature: Bytesheader_hash: Bytesheader_epoch: u32header_nonce: u64header_shard_id: u32header_round: u64is_start_of_epoch: boolTrait Implementations
Sourceimpl Clone for HeaderProof
impl Clone for HeaderProof
Sourcefn clone(&self) -> HeaderProof
fn clone(&self) -> HeaderProof
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HeaderProof
impl Debug for HeaderProof
Sourceimpl Default for HeaderProof
impl Default for HeaderProof
Sourceimpl Hash for HeaderProof
impl Hash for HeaderProof
Sourceimpl Message for HeaderProof
impl Message for HeaderProof
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for HeaderProof
impl PartialEq for HeaderProof
impl Eq for HeaderProof
impl StructuralPartialEq for HeaderProof