pub struct HeartbeatV2 {
pub payload: Bytes,
pub version_number: String,
pub node_display_name: String,
pub identity: String,
pub nonce: u64,
pub peer_sub_type: u32,
pub pubkey: Bytes,
pub num_trie_nodes_synced: u64,
}Expand description
HeartbeatV2 represents the heartbeat message that is sent between peers from the same shard containing current node status
Fields
payload: Bytesversion_number: Stringnode_display_name: Stringidentity: Stringnonce: u64peer_sub_type: u32pubkey: Bytesnum_trie_nodes_synced: u64Trait Implementations
Sourceimpl Clone for HeartbeatV2
impl Clone for HeartbeatV2
Sourcefn clone(&self) -> HeartbeatV2
fn clone(&self) -> HeartbeatV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HeartbeatV2
impl Debug for HeartbeatV2
Sourceimpl Default for HeartbeatV2
impl Default for HeartbeatV2
Sourceimpl Hash for HeartbeatV2
impl Hash for HeartbeatV2
Sourceimpl Message for HeartbeatV2
impl Message for HeartbeatV2
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for HeartbeatV2
impl PartialEq for HeartbeatV2
impl Eq for HeartbeatV2
impl StructuralPartialEq for HeartbeatV2