pub struct MetaBlock {Show 25 fields
pub nonce: u64,
pub epoch: u32,
pub round: u64,
pub time_stamp: u64,
pub shard_info: Vec<ShardData>,
pub peer_info: Vec<PeerData>,
pub signature: Bytes,
pub leader_signature: Bytes,
pub pub_keys_bitmap: Bytes,
pub prev_hash: Bytes,
pub prev_rand_seed: Bytes,
pub rand_seed: Bytes,
pub root_hash: Bytes,
pub validator_stats_root_hash: Bytes,
pub mini_block_headers: Vec<MiniBlockHeader>,
pub receipts_hash: Bytes,
pub epoch_start: Option<EpochStart>,
pub chain_id: Bytes,
pub software_version: Bytes,
pub accumulated_fees: Bytes,
pub accumulated_fees_in_epoch: Bytes,
pub developer_fees: Bytes,
pub dev_fees_in_epoch: Bytes,
pub tx_count: u32,
pub reserved: Bytes,
}Expand description
MetaBlock holds the data that will be saved to the metachain each round
Fields
nonce: u64epoch: u32round: u64time_stamp: u64shard_info: Vec<ShardData>peer_info: Vec<PeerData>signature: Bytesleader_signature: Bytespub_keys_bitmap: Bytesprev_hash: Bytesprev_rand_seed: Bytesrand_seed: Bytesroot_hash: Bytesvalidator_stats_root_hash: Bytesmini_block_headers: Vec<MiniBlockHeader>receipts_hash: Bytesepoch_start: Option<EpochStart>chain_id: Bytessoftware_version: Bytesaccumulated_fees: Bytesaccumulated_fees_in_epoch: Bytesdeveloper_fees: Bytesdev_fees_in_epoch: Bytestx_count: u32reserved: BytesTrait Implementations
Sourceimpl Message for MetaBlock
impl Message for MetaBlock
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for MetaBlock