pub struct MetaBlockV3 {Show 21 fields
pub nonce: u64,
pub epoch: u32,
pub round: u64,
pub timestamp_ms: u64,
pub shard_info: Vec<ShardData>,
pub peer_info: Vec<PeerData>,
pub leader_signature: Bytes,
pub prev_hash: Bytes,
pub prev_rand_seed: Bytes,
pub rand_seed: Bytes,
pub mini_block_headers: Vec<MiniBlockHeader>,
pub epoch_change_proposed: bool,
pub epoch_start: Option<EpochStart>,
pub chain_id: Bytes,
pub software_version: Bytes,
pub reserved: Bytes,
pub gas_limit: u64,
pub tx_count: u32,
pub last_execution_result: Option<MetaExecutionResultInfo>,
pub execution_results: Vec<MetaExecutionResult>,
pub shard_info_proposal: Vec<ShardDataProposal>,
}Expand description
MetaBlockV3 holds all the fields needed for a meta block v3. This is the part that is being hashed and run through consensus.
Fields
nonce: u64epoch: u32round: u64timestamp_ms: u64shard_info: Vec<ShardData>peer_info: Vec<PeerData>leader_signature: Bytesprev_hash: Bytesprev_rand_seed: Bytesrand_seed: Bytesmini_block_headers: Vec<MiniBlockHeader>epoch_change_proposed: boolepoch_start: Option<EpochStart>chain_id: Bytessoftware_version: Bytesreserved: Bytesgas_limit: u64tx_count: u32last_execution_result: Option<MetaExecutionResultInfo>execution_results: Vec<MetaExecutionResult>shard_info_proposal: Vec<ShardDataProposal>Trait Implementations
Sourceimpl Clone for MetaBlockV3
impl Clone for MetaBlockV3
Sourcefn clone(&self) -> MetaBlockV3
fn clone(&self) -> MetaBlockV3
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaBlockV3
impl Debug for MetaBlockV3
Sourceimpl Default for MetaBlockV3
impl Default for MetaBlockV3
Sourceimpl Message for MetaBlockV3
impl Message for MetaBlockV3
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MetaBlockV3
impl PartialEq for MetaBlockV3
impl StructuralPartialEq for MetaBlockV3