pub struct MetaExecutionResult {
pub execution_result: Option<BaseMetaExecutionResult>,
pub mini_block_headers: Vec<MiniBlockHeader>,
pub receipts_hash: Bytes,
pub developer_fees: Bytes,
pub accumulated_fees: Bytes,
pub executed_tx_count: u64,
}Expand description
MetaExecutionResult contains a base meta execution result and extra fields for meta block results
Fields
execution_result: Option<BaseMetaExecutionResult>mini_block_headers: Vec<MiniBlockHeader>receipts_hash: Bytesdeveloper_fees: Bytesaccumulated_fees: Bytesexecuted_tx_count: u64Trait Implementations
Sourceimpl Clone for MetaExecutionResult
impl Clone for MetaExecutionResult
Sourcefn clone(&self) -> MetaExecutionResult
fn clone(&self) -> MetaExecutionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaExecutionResult
impl Debug for MetaExecutionResult
Sourceimpl Default for MetaExecutionResult
impl Default for MetaExecutionResult
Sourceimpl Message for MetaExecutionResult
impl Message for MetaExecutionResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MetaExecutionResult
impl PartialEq for MetaExecutionResult
impl StructuralPartialEq for MetaExecutionResult