pub struct MetaTriggerRegistryV3 {
pub epoch: u32,
pub current_round: u64,
pub epoch_finality_attesting_round: u64,
pub curr_epoch_start_round: u64,
pub prev_epoch_start_round: u64,
pub epoch_start_meta_hash: Bytes,
pub epoch_change_proposed: bool,
pub epoch_start_meta: Option<MetaBlockV3>,
}Fields
epoch: u32current_round: u64epoch_finality_attesting_round: u64curr_epoch_start_round: u64prev_epoch_start_round: u64epoch_start_meta_hash: Bytesepoch_change_proposed: boolepoch_start_meta: Option<MetaBlockV3>Trait Implementations
Sourceimpl Clone for MetaTriggerRegistryV3
impl Clone for MetaTriggerRegistryV3
Sourcefn clone(&self) -> MetaTriggerRegistryV3
fn clone(&self) -> MetaTriggerRegistryV3
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaTriggerRegistryV3
impl Debug for MetaTriggerRegistryV3
Sourceimpl Default for MetaTriggerRegistryV3
impl Default for MetaTriggerRegistryV3
Sourceimpl Message for MetaTriggerRegistryV3
impl Message for MetaTriggerRegistryV3
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MetaTriggerRegistryV3
impl PartialEq for MetaTriggerRegistryV3
impl StructuralPartialEq for MetaTriggerRegistryV3