pub struct MiniBlockHeaderReserved {
pub execution_type: i32,
pub state: i32,
pub index_of_first_tx_processed: i32,
pub index_of_last_tx_processed: i32,
}Fields
execution_type: i32state: i32index_of_first_tx_processed: i32index_of_last_tx_processed: i32Implementations
Sourceimpl MiniBlockHeaderReserved
impl MiniBlockHeaderReserved
Sourcepub fn execution_type(&self) -> ProcessingType
pub fn execution_type(&self) -> ProcessingType
Returns the enum value of execution_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execution_type(&mut self, value: ProcessingType)
pub fn set_execution_type(&mut self, value: ProcessingType)
Sets execution_type to the provided enum value.
Sourcepub fn state(&self) -> MiniBlockState
pub fn state(&self) -> MiniBlockState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: MiniBlockState)
pub fn set_state(&mut self, value: MiniBlockState)
Sets state to the provided enum value.