pub struct MiniBlocksInMeta {
pub meta_hash: Bytes,
pub mini_blocks_hashes: Vec<Bytes>,
pub fully_processed: Vec<bool>,
pub index_of_last_tx_processed: Vec<i32>,
}Expand description
MiniBlocksInMeta is used to store all mini blocks hashes for a metablock hash
Fields
meta_hash: Bytesmini_blocks_hashes: Vec<Bytes>fully_processed: Vec<bool>index_of_last_tx_processed: Vec<i32>Trait Implementations
Sourceimpl Clone for MiniBlocksInMeta
impl Clone for MiniBlocksInMeta
Sourcefn clone(&self) -> MiniBlocksInMeta
fn clone(&self) -> MiniBlocksInMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MiniBlocksInMeta
impl Debug for MiniBlocksInMeta
Sourceimpl Default for MiniBlocksInMeta
impl Default for MiniBlocksInMeta
Sourceimpl Hash for MiniBlocksInMeta
impl Hash for MiniBlocksInMeta
Sourceimpl Message for MiniBlocksInMeta
impl Message for MiniBlocksInMeta
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MiniBlocksInMeta
impl PartialEq for MiniBlocksInMeta
impl Eq for MiniBlocksInMeta
impl StructuralPartialEq for MiniBlocksInMeta