pub struct MiniblockMetadata {Show 13 fields
pub source_shard_id: u32,
pub destination_shard_id: u32,
pub round: u64,
pub header_nonce: u64,
pub header_hash: Bytes,
pub miniblock_hash: Bytes,
pub deprecated_status: Bytes,
pub epoch: u32,
pub notarized_at_source_in_meta_nonce: u64,
pub notarized_at_destination_in_meta_nonce: u64,
pub notarized_at_source_in_meta_hash: Bytes,
pub notarized_at_destination_in_meta_hash: Bytes,
pub type: i32,
}Expand description
MiniblockMetadata is used to store information about a history transaction
Fields
source_shard_id: u32destination_shard_id: u32round: u64header_nonce: u64header_hash: Bytesminiblock_hash: Bytesdeprecated_status: Bytes👎Deprecated
epoch: u32notarized_at_source_in_meta_nonce: u64notarized_at_destination_in_meta_nonce: u64notarized_at_source_in_meta_hash: Bytesnotarized_at_destination_in_meta_hash: Bytestype: i32Trait Implementations
Sourceimpl Clone for MiniblockMetadata
impl Clone for MiniblockMetadata
Sourcefn clone(&self) -> MiniblockMetadata
fn clone(&self) -> MiniblockMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MiniblockMetadata
impl Debug for MiniblockMetadata
Sourceimpl Default for MiniblockMetadata
impl Default for MiniblockMetadata
Sourceimpl Hash for MiniblockMetadata
impl Hash for MiniblockMetadata
Sourceimpl Message for MiniblockMetadata
impl Message for MiniblockMetadata
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MiniblockMetadata
impl PartialEq for MiniblockMetadata
impl Eq for MiniblockMetadata
impl StructuralPartialEq for MiniblockMetadata