pub struct OutportBlock {Show 14 fields
pub shard_id: u32,
pub block_data: Option<BlockData>,
pub transaction_pool: Option<TransactionPool>,
pub header_gas_consumption: Option<HeaderGasConsumption>,
pub altered_accounts: HashMap<String, AlteredAccount>,
pub notarized_headers_hashes: Vec<String>,
pub number_of_shards: u32,
pub signers_indexes: Vec<u64>,
pub highest_final_block_nonce: u64,
pub highest_final_block_hash: Bytes,
pub leader_index: u64,
pub leader_bls_key: Bytes,
pub state_accesses: HashMap<String, StateAccesses>,
pub state_accesses_for_block: HashMap<String, StateAccessesForBlock>,
}Fields
shard_id: u32block_data: Option<BlockData>transaction_pool: Option<TransactionPool>header_gas_consumption: Option<HeaderGasConsumption>altered_accounts: HashMap<String, AlteredAccount>notarized_headers_hashes: Vec<String>number_of_shards: u32signers_indexes: Vec<u64>highest_final_block_nonce: u64highest_final_block_hash: Bytesleader_index: u64leader_bls_key: Bytesstate_accesses: HashMap<String, StateAccesses>state_accesses_for_block: HashMap<String, StateAccessesForBlock>Trait Implementations
Sourceimpl Clone for OutportBlock
impl Clone for OutportBlock
Sourcefn clone(&self) -> OutportBlock
fn clone(&self) -> OutportBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutportBlock
impl Debug for OutportBlock
Sourceimpl Default for OutportBlock
impl Default for OutportBlock
Sourceimpl Message for OutportBlock
impl Message for OutportBlock
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OutportBlock
impl PartialEq for OutportBlock
impl StructuralPartialEq for OutportBlock