pub struct PeerAccountData {Show 20 fields
pub bls_public_key: Bytes,
pub reward_address: Bytes,
pub shard_id: u32,
pub validator_success_rate: Option<SignRate>,
pub leader_success_rate: Option<SignRate>,
pub validator_ignored_signatures_rate: u32,
pub rating: u32,
pub temp_rating: u32,
pub accumulated_fees: Bytes,
pub num_selected_in_success_blocks: u32,
pub index_in_list: u32,
pub list: String,
pub consecutive_proposer_misses: u32,
pub total_validator_success_rate: Option<SignRate>,
pub total_leader_success_rate: Option<SignRate>,
pub total_validator_ignored_signatures_rate: u32,
pub nonce: u64,
pub un_staked_epoch: u32,
pub previous_list: String,
pub previous_index_in_list: u32,
}Expand description
PeerAccountData represents the data that defines the PeerAccount
Fields
bls_public_key: Bytesreward_address: Bytesshard_id: u32validator_success_rate: Option<SignRate>leader_success_rate: Option<SignRate>validator_ignored_signatures_rate: u32rating: u32temp_rating: u32accumulated_fees: Bytesnum_selected_in_success_blocks: u32index_in_list: u32list: Stringconsecutive_proposer_misses: u32total_validator_success_rate: Option<SignRate>total_leader_success_rate: Option<SignRate>total_validator_ignored_signatures_rate: u32nonce: u64un_staked_epoch: u32previous_list: Stringprevious_index_in_list: u32Trait Implementations
Sourceimpl Clone for PeerAccountData
impl Clone for PeerAccountData
Sourcefn clone(&self) -> PeerAccountData
fn clone(&self) -> PeerAccountData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeerAccountData
impl Debug for PeerAccountData
Sourceimpl Default for PeerAccountData
impl Default for PeerAccountData
Sourceimpl Hash for PeerAccountData
impl Hash for PeerAccountData
Sourceimpl Message for PeerAccountData
impl Message for PeerAccountData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PeerAccountData
impl PartialEq for PeerAccountData
impl Eq for PeerAccountData
impl StructuralPartialEq for PeerAccountData