pub struct PeerData {
pub address: Bytes,
pub public_key: Bytes,
pub action: i32,
pub time_stamp: u64,
pub value_change: Bytes,
}Expand description
PeerData holds information about actions taken by a peer:
- a peer can register with an amount to become a validator
- a peer can choose to deregister and get back the deposited value
Fields
address: Bytespublic_key: Bytesaction: i32time_stamp: u64value_change: BytesImplementations
Sourceimpl PeerData
impl PeerData
Sourcepub fn action(&self) -> PeerAction
pub fn action(&self) -> PeerAction
Returns the enum value of action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: PeerAction)
pub fn set_action(&mut self, value: PeerAction)
Sets action to the provided enum value.