pub struct RequestData {
pub type: i32,
pub value: Bytes,
pub epoch: u32,
pub chunk_index: u32,
}Expand description
RequestData holds the requested data This struct will be serialized and sent to the other peers
Fields
type: i32value: Bytesepoch: u32chunk_index: u32Implementations
Sourceimpl RequestData
impl RequestData
Sourcepub fn type(&self) -> RequestDataType
pub fn type(&self) -> RequestDataType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: RequestDataType)
pub fn set_type(&mut self, value: RequestDataType)
Sets type to the provided enum value.