pub struct ShardTriggerRegistry {
pub is_epoch_start: bool,
pub new_epoch_header_received: bool,
pub epoch: u32,
pub meta_epoch: u32,
pub current_round_index: i64,
pub epoch_start_round: u64,
pub epoch_finality_attesting_round: u64,
pub epoch_meta_block_hash: Bytes,
pub epoch_start_shard_header: Option<Header>,
}Fields
is_epoch_start: boolnew_epoch_header_received: boolepoch: u32meta_epoch: u32current_round_index: i64epoch_start_round: u64epoch_finality_attesting_round: u64epoch_meta_block_hash: Bytesepoch_start_shard_header: Option<Header>Trait Implementations
Sourceimpl Clone for ShardTriggerRegistry
impl Clone for ShardTriggerRegistry
Sourcefn clone(&self) -> ShardTriggerRegistry
fn clone(&self) -> ShardTriggerRegistry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShardTriggerRegistry
impl Debug for ShardTriggerRegistry
Sourceimpl Default for ShardTriggerRegistry
impl Default for ShardTriggerRegistry
Sourceimpl Message for ShardTriggerRegistry
impl Message for ShardTriggerRegistry
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ShardTriggerRegistry
impl PartialEq for ShardTriggerRegistry
impl StructuralPartialEq for ShardTriggerRegistry