pub struct SmartContractResult {Show 16 fields
pub nonce: u64,
pub value: Bytes,
pub rcv_addr: Bytes,
pub snd_addr: Bytes,
pub relayer_addr: Bytes,
pub relayed_value: Bytes,
pub code: Bytes,
pub data: Bytes,
pub prev_tx_hash: Bytes,
pub original_tx_hash: Bytes,
pub gas_limit: u64,
pub gas_price: u64,
pub call_type: i64,
pub code_metadata: Bytes,
pub return_message: Bytes,
pub original_sender: Bytes,
}Fields
nonce: u64value: Bytesrcv_addr: Bytessnd_addr: Bytesrelayer_addr: Bytesrelayed_value: Bytescode: Bytesdata: Bytesprev_tx_hash: Bytesoriginal_tx_hash: Bytesgas_limit: u64gas_price: u64call_type: i64code_metadata: Bytesreturn_message: Bytesoriginal_sender: BytesTrait Implementations
Sourceimpl Clone for SmartContractResult
impl Clone for SmartContractResult
Sourcefn clone(&self) -> SmartContractResult
fn clone(&self) -> SmartContractResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SmartContractResult
impl Debug for SmartContractResult
Sourceimpl Default for SmartContractResult
impl Default for SmartContractResult
Sourceimpl Hash for SmartContractResult
impl Hash for SmartContractResult
Sourceimpl Message for SmartContractResult
impl Message for SmartContractResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SmartContractResult
impl PartialEq for SmartContractResult
impl Eq for SmartContractResult
impl StructuralPartialEq for SmartContractResult