pub struct StakedDataV10 {
pub register_nonce: u64,
pub staked_nonce: u64,
pub staked: bool,
pub un_staked_nonce: u64,
pub un_staked_epoch: u32,
pub reward_address: Bytes,
pub stake_value: Bytes,
pub jailed_round: u64,
pub jailed_nonce: u64,
pub un_jailed_nonce: u64,
pub jailed: bool,
pub waiting: bool,
}Fields
register_nonce: u64staked_nonce: u64staked: boolun_staked_nonce: u64un_staked_epoch: u32reward_address: Bytesstake_value: Bytesjailed_round: u64jailed_nonce: u64un_jailed_nonce: u64jailed: boolwaiting: boolTrait Implementations
Sourceimpl Clone for StakedDataV10
impl Clone for StakedDataV10
Sourcefn clone(&self) -> StakedDataV10
fn clone(&self) -> StakedDataV10
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StakedDataV10
impl Debug for StakedDataV10
Sourceimpl Default for StakedDataV10
impl Default for StakedDataV10
Sourceimpl Hash for StakedDataV10
impl Hash for StakedDataV10
Sourceimpl Message for StakedDataV10
impl Message for StakedDataV10
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StakedDataV10
impl PartialEq for StakedDataV10
impl Eq for StakedDataV10
impl StructuralPartialEq for StakedDataV10