pub struct StakedDataV20 {Show 15 fields
pub register_nonce: u64,
pub staked_nonce: u64,
pub staked: bool,
pub un_staked_nonce: u64,
pub un_staked_epoch: u32,
pub reward_address: Bytes,
pub stake_value: Bytes,
pub jailed_round: u64,
pub jailed_nonce: u64,
pub un_jailed_nonce: u64,
pub jailed: bool,
pub waiting: bool,
pub num_jailed: u32,
pub slash_value: Bytes,
pub owner_address: Bytes,
}Fields
register_nonce: u64staked_nonce: u64staked: boolun_staked_nonce: u64un_staked_epoch: u32reward_address: Bytesstake_value: Bytesjailed_round: u64jailed_nonce: u64un_jailed_nonce: u64jailed: boolwaiting: boolnum_jailed: u32slash_value: Bytesowner_address: BytesTrait Implementations
Sourceimpl Clone for StakedDataV20
impl Clone for StakedDataV20
Sourcefn clone(&self) -> StakedDataV20
fn clone(&self) -> StakedDataV20
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StakedDataV20
impl Debug for StakedDataV20
Sourceimpl Default for StakedDataV20
impl Default for StakedDataV20
Sourceimpl Hash for StakedDataV20
impl Hash for StakedDataV20
Sourceimpl Message for StakedDataV20
impl Message for StakedDataV20
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StakedDataV20
impl PartialEq for StakedDataV20
impl Eq for StakedDataV20
impl StructuralPartialEq for StakedDataV20