pub struct StateAccess {
pub type: i32,
pub index: i32,
pub tx_hash: Bytes,
pub main_trie_key: Bytes,
pub main_trie_val: Bytes,
pub operation: u32,
pub data_trie_changes: Vec<DataTrieChange>,
pub account_changes: u32,
}Fields
type: i32index: i32tx_hash: Bytesmain_trie_key: Bytesmain_trie_val: Bytesoperation: u32data_trie_changes: Vec<DataTrieChange>account_changes: u32Implementations
Sourceimpl StateAccess
impl StateAccess
Sourcepub fn type(&self) -> ActionType
pub fn type(&self) -> ActionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ActionType)
pub fn set_type(&mut self, value: ActionType)
Sets type to the provided enum value.