pub struct Transaction {Show 17 fields
pub nonce: u64,
pub value: Bytes,
pub rcv_addr: Bytes,
pub rcv_user_name: Bytes,
pub snd_addr: Bytes,
pub snd_user_name: Bytes,
pub gas_price: u64,
pub gas_limit: u64,
pub data: Bytes,
pub chain_id: Bytes,
pub version: u32,
pub signature: Bytes,
pub options: u32,
pub guardian_addr: Bytes,
pub guardian_signature: Bytes,
pub relayer_addr: Bytes,
pub relayer_signature: Bytes,
}Expand description
Transaction holds all the data needed for a value transfer or SC call
Fields
nonce: u64value: Bytesrcv_addr: Bytesrcv_user_name: Bytessnd_addr: Bytessnd_user_name: Bytesgas_price: u64gas_limit: u64data: Byteschain_id: Bytesversion: u32signature: Bytesoptions: u32guardian_addr: Bytesguardian_signature: Bytesrelayer_addr: Bytesrelayer_signature: BytesImplementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn signing_bytes(&self) -> Result<Vec<u8>, ConversionError>
pub fn signing_bytes(&self) -> Result<Vec<u8>, ConversionError>
Serializes a protobuf transaction into the canonical JSON payload used for signing.
Sourceimpl Transaction
impl Transaction
Sourcepub const HASH_SIZE: usize = 32
pub const HASH_SIZE: usize = 32
Length in bytes of the transaction hash computed by the network (BLAKE2b-256).
Sourcepub fn compute_hash(&self) -> [u8; 32]
pub fn compute_hash(&self) -> [u8; 32]
Computes the canonical transaction hash by re-encoding the message and hashing it with BLAKE2b-256, mirroring the logic from the Go implementation.
Sourcepub fn get_tx_hash(&self) -> [u8; 32]
pub fn get_tx_hash(&self) -> [u8; 32]
Computes the canonical transaction hash by re-encoding the message and hashing it with BLAKE2b-256.
Sourcepub fn hash_bytes(bytes: &[u8]) -> [u8; 32]
pub fn hash_bytes(bytes: &[u8]) -> [u8; 32]
Hashes an already serialized transaction buffer with BLAKE2b-256.
Sourcepub fn sender_address_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn sender_address_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the sender address encoded as an erd Bech32 string if present.
Sourcepub fn sender_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn sender_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the sender address encoded as an erd Bech32 string if present.
Sourcepub fn receiver_address_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn receiver_address_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the receiver address encoded as an erd Bech32 string if present.
Sourcepub fn receiver_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn receiver_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the receiver address encoded as an erd Bech32 string if present.
Sourcepub fn guardian_address_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn guardian_address_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the guardian address encoded as an erd Bech32 string if present.
Sourcepub fn guardian_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn guardian_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the guardian address encoded as an erd Bech32 string if present.
Sourcepub fn relayer_address_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn relayer_address_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the relayer address encoded as an erd Bech32 string if present.
Sourcepub fn relayer_bech32(&self) -> Result<Option<String>, EncodeError>
pub fn relayer_bech32(&self) -> Result<Option<String>, EncodeError>
Returns the relayer address encoded as an erd Bech32 string if present.