pub struct TransactionPool {
pub transactions: HashMap<String, TxInfo>,
pub smart_contract_results: HashMap<String, ScrInfo>,
pub rewards: HashMap<String, RewardInfo>,
pub receipts: HashMap<String, Receipt>,
pub invalid_txs: HashMap<String, TxInfo>,
pub logs: Vec<LogData>,
pub scheduled_executed_scrs_hashes_prev_block: Vec<String>,
pub scheduled_executed_invalid_txs_hashes_prev_block: Vec<String>,
pub unexecutable_transactions: HashMap<String, Transaction>,
}Fields
transactions: HashMap<String, TxInfo>smart_contract_results: HashMap<String, ScrInfo>rewards: HashMap<String, RewardInfo>receipts: HashMap<String, Receipt>invalid_txs: HashMap<String, TxInfo>logs: Vec<LogData>scheduled_executed_scrs_hashes_prev_block: Vec<String>scheduled_executed_invalid_txs_hashes_prev_block: Vec<String>unexecutable_transactions: HashMap<String, Transaction>Trait Implementations
Sourceimpl Clone for TransactionPool
impl Clone for TransactionPool
Sourcefn clone(&self) -> TransactionPool
fn clone(&self) -> TransactionPool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionPool
impl Debug for TransactionPool
Sourceimpl Default for TransactionPool
impl Default for TransactionPool
Sourceimpl Message for TransactionPool
impl Message for TransactionPool
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TransactionPool
impl PartialEq for TransactionPool
impl StructuralPartialEq for TransactionPool