pub struct ValidatorDataV2 {
pub register_nonce: u64,
pub epoch: u32,
pub reward_address: Bytes,
pub total_stake_value: Bytes,
pub locked_stake: Bytes,
pub max_stake_per_node: Bytes,
pub bls_pub_keys: Vec<Bytes>,
pub num_registered: u32,
pub unstaked_info: Vec<UnstakedValue>,
pub total_unstaked: Bytes,
pub total_slashed: Bytes,
}Fields
register_nonce: u64epoch: u32reward_address: Bytestotal_stake_value: Byteslocked_stake: Bytesmax_stake_per_node: Bytesbls_pub_keys: Vec<Bytes>num_registered: u32unstaked_info: Vec<UnstakedValue>total_unstaked: Bytestotal_slashed: BytesTrait Implementations
Sourceimpl Clone for ValidatorDataV2
impl Clone for ValidatorDataV2
Sourcefn clone(&self) -> ValidatorDataV2
fn clone(&self) -> ValidatorDataV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorDataV2
impl Debug for ValidatorDataV2
Sourceimpl Default for ValidatorDataV2
impl Default for ValidatorDataV2
Sourceimpl Message for ValidatorDataV2
impl Message for ValidatorDataV2
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ValidatorDataV2
impl PartialEq for ValidatorDataV2
impl StructuralPartialEq for ValidatorDataV2