pub struct ValidatorInfo {Show 22 fields
pub public_key: Bytes,
pub shard_id: u32,
pub list: String,
pub index: u32,
pub temp_rating: u32,
pub rating: u32,
pub rating_modifier: f32,
pub reward_address: Bytes,
pub leader_success: u32,
pub leader_failure: u32,
pub validator_success: u32,
pub validator_failure: u32,
pub validator_ignored_signatures: u32,
pub num_selected_in_success_blocks: u32,
pub accumulated_fees: Bytes,
pub total_leader_success: u32,
pub total_leader_failure: u32,
pub total_validator_success: u32,
pub total_validator_failure: u32,
pub total_validator_ignored_signatures: u32,
pub previous_list: String,
pub previous_index: u32,
}Expand description
ValidatorInfo represents the data regarding a validator that is verified by the metaNodes
Fields
public_key: Bytesshard_id: u32list: Stringindex: u32temp_rating: u32rating: u32rating_modifier: f32reward_address: Bytesleader_success: u32leader_failure: u32validator_success: u32validator_failure: u32validator_ignored_signatures: u32num_selected_in_success_blocks: u32accumulated_fees: Bytestotal_leader_success: u32total_leader_failure: u32total_validator_success: u32total_validator_failure: u32total_validator_ignored_signatures: u32previous_list: Stringprevious_index: u32Trait Implementations
Sourceimpl Clone for ValidatorInfo
impl Clone for ValidatorInfo
Sourcefn clone(&self) -> ValidatorInfo
fn clone(&self) -> ValidatorInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorInfo
impl Debug for ValidatorInfo
Sourceimpl Default for ValidatorInfo
impl Default for ValidatorInfo
Sourceimpl Message for ValidatorInfo
impl Message for ValidatorInfo
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ValidatorInfo
impl PartialEq for ValidatorInfo
impl StructuralPartialEq for ValidatorInfo