pub struct ValidatorStatistics {Show 15 fields
pub temp_rating: f32,
pub num_leader_success: u32,
pub num_leader_failure: u32,
pub num_validator_success: u32,
pub num_validator_failure: u32,
pub num_validator_ignored_signatures: u32,
pub rating: f32,
pub rating_modifier: f32,
pub total_num_leader_success: u32,
pub total_num_leader_failure: u32,
pub total_num_validator_success: u32,
pub total_num_validator_failure: u32,
pub total_num_validator_ignored_signatures: u32,
pub shard_id: u32,
pub validator_status: String,
}Expand description
ValidatorStatistics holds information about a validator
Fields
temp_rating: f32num_leader_success: u32num_leader_failure: u32num_validator_success: u32num_validator_failure: u32num_validator_ignored_signatures: u32rating: f32rating_modifier: f32total_num_leader_success: u32total_num_leader_failure: u32total_num_validator_success: u32total_num_validator_failure: u32total_num_validator_ignored_signatures: u32shard_id: u32validator_status: StringTrait Implementations
Sourceimpl Clone for ValidatorStatistics
impl Clone for ValidatorStatistics
Sourcefn clone(&self) -> ValidatorStatistics
fn clone(&self) -> ValidatorStatistics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorStatistics
impl Debug for ValidatorStatistics
Sourceimpl Default for ValidatorStatistics
impl Default for ValidatorStatistics
Sourceimpl Message for ValidatorStatistics
impl Message for ValidatorStatistics
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ValidatorStatistics
impl PartialEq for ValidatorStatistics
impl StructuralPartialEq for ValidatorStatistics