#[repr(i32)]pub enum SerializableAsyncCallStatus {
SerializableAsyncCallPending = 0,
SerializableAsyncCallResolved = 1,
SerializableAsyncCallRejected = 2,
}Variants
SerializableAsyncCallPending = 0
SerializableAsyncCallResolved = 1
SerializableAsyncCallRejected = 2
Implementations
Sourceimpl SerializableAsyncCallStatus
impl SerializableAsyncCallStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of SerializableAsyncCallStatus.
Sourcepub fn from_i32(value: i32) -> Option<SerializableAsyncCallStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SerializableAsyncCallStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SerializableAsyncCallStatus, or None if value is not a valid variant.
Sourceimpl SerializableAsyncCallStatus
impl SerializableAsyncCallStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.