pub struct SerializableAsyncCall {
pub call_id: Bytes,
pub status: i32,
pub execution_mode: i32,
pub destination: Bytes,
pub data: Bytes,
pub gas_limit: u64,
pub gas_locked: u64,
pub value_bytes: Bytes,
pub success_callback: String,
pub error_callback: String,
pub callback_closure: Bytes,
}Fields
call_id: Bytesstatus: i32execution_mode: i32destination: Bytesdata: Bytesgas_limit: u64gas_locked: u64value_bytes: Bytessuccess_callback: Stringerror_callback: Stringcallback_closure: BytesImplementations
Sourceimpl SerializableAsyncCall
impl SerializableAsyncCall
Sourcepub fn status(&self) -> SerializableAsyncCallStatus
pub fn status(&self) -> SerializableAsyncCallStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SerializableAsyncCallStatus)
pub fn set_status(&mut self, value: SerializableAsyncCallStatus)
Sets status to the provided enum value.
Sourcepub fn execution_mode(&self) -> SerializableAsyncCallExecutionMode
pub fn execution_mode(&self) -> SerializableAsyncCallExecutionMode
Returns the enum value of execution_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execution_mode(&mut self, value: SerializableAsyncCallExecutionMode)
pub fn set_execution_mode(&mut self, value: SerializableAsyncCallExecutionMode)
Sets execution_mode to the provided enum value.